@@ -1,9 +1,13 @@
-__package__ = 'hivy'
+'''
+TODO: Doc
+'''
+
+__project__ = 'hivy'
 __author__ = 'Xavier Bruhiere'
 __copyright__ = 'Hive Tech, SAS'
 __licence__ = 'Apache 2.0'
-__version__ = '0.0.2'
-__doc__ = {
+__version__ = '0.0.3'
+__api__ = {
     'status': 'GET /status',
     'version': 'GET /version',
     'doc': 'GET /doc',
