@@ -21,12 +21,12 @@ Options:
 '''
 
 
-from flask import Flask
+from flask import Flask, request
 from flask.ext import restful
 from docopt import docopt
 
-import hivy.system as system
-import hivy.node as node
+import hivy.resources.system as system
+import hivy.resources.node as node
 
 
 app = Flask(__name__)
@@ -42,6 +42,18 @@ api.add_resource(system.Doc, '/doc')
 api.add_resource(node.RestNode, '/node')
 
 
+#TODO Use it for logging and perfs
+@app.before_request
+def before_request():
+    print request
+
+
+@app.after_request
+def after_request(response):
+    print response
+    return response
+
+
 if __name__ == '__main__':
     args = docopt(__doc__, version='Hivy, Hive api 0.0.1')
 
